<?php

namespace Fgm\ComposerCheck\Tests;

use Fgm\ComposerCheck\LoaderFactory;

/**
 * Class LoaderFactoryTest.
 *
 * @coversDefaultClass \Fgm\ComposerCheck\LoaderFactory
 */
class LoaderFactoryTest extends \PHPUnit_Framework_TestCase {
  const NS = 'Fgm\\ComposerCheck\\';

  /**
   */
  public function testHappyConstructor() {
    // This is a Composer project, so it should be installed to run its tests.
    $dir =  __DIR__ . '/../..';
    $factory = new LoaderFactory($dir);
    $this->assertInstanceOf(self::NS . 'LoaderFactory', $factory);
  }

  /**
   * @expectedException \InvalidArgumentException
   */
  public function testSadConstructorMissing() {
    $dir =  __DIR__;
    new LoaderFactory($dir);
  }

  /**
   * @expectedException \InvalidArgumentException
   */
  public function testSadConstructorInvalid() {
    $dir =  '/dev/null/nowhere';
    new LoaderFactory($dir);
  }

  public function testHappyCreateLoader() {
    $dir = __DIR__ . '/../..';
    $factory = new LoaderFactory($dir);
    $loader = $factory->createLoader('requirements');
    $this->assertInstanceOf(self::NS . 'RequirementsLoader', $loader);

    $loader = $factory->createLoader('lock');
    $this->assertInstanceOf(self::NS . 'LockLoader', $loader);
  }

  /**
   * @expectedException \InvalidArgumentException
   */
  public function testSadCreateLoader() {
    $dir = __DIR__ . '/../..';
    $factory = new LoaderFactory($dir);
    $factory->createLoader('invalid');
  }
}
