<?php

/**
 * @file
 * A Drush plugin to compare composer.json and composer.lock.
 */

use Drupal\Component\Utility\Unicode;
use Fgm\ComposerCheck\DrushReporter;
use Fgm\ComposerCheck\LoaderFactory;
use Fgm\ComposerCheck\YamlReporter;
use Symfony\Component\Yaml\Yaml;

/**
 * Implements hook_drush_command().
 */
function composer_check_drush_command() {
  $cmds['composer-check'] = [
    'aliases' => ['cck'],
    'description' => 'Lists the packages requested in composer.json and the matching locked version.',
    'arguments' => [
      'composer.lock' => 'The path to the lock file. Defaults to the one in drupal root.',
    ],
    'options' => [
      'all' => [
        'description' => 'List all locked packages, even those not requested',
        'required' => FALSE,
      ],
      'yaml' => 'Produce YAML output instead of a table',
    ],
  ];

  return $cmds;
}

/**
 * Command callback for composer-check.
 *
 * @param null|string $path
 *   Optional. The path to a directory holding a composer.[json|lock] file pair.
 */
function drush_composer_check($path = DRUPAL_ROOT) {
  $all = !!drush_get_option('all');
  $useYaml = !!drush_get_option('yaml');

  $factory = new LoaderFactory($path, $all);
  $requirementsLoader = $factory->createLoader('requirements');
  $lockLoader = $factory->createLoader('lock');

  $merger = new Merger($requirementsLoader, $lockLoader);

  $reporter = $useYaml ? new YamlReporter() : new DrushReporter();
  $reporter->report($merger);
}
